@@ -1,6 +1,8 @@
 #ifndef __ENCODER_H_
 #define __ENCODER_H_
 
+#ifdef __cplusplus
+
 #include "icsneo/communication/message/message.h"
 #include "icsneo/communication/message/canmessage.h"
 #include "icsneo/communication/packet.h"
@@ -17,16 +19,17 @@ class Encoder {
 public:
 	Encoder(device_eventhandler_t report) : report(report) {}
 	bool encode(const Packetizer& packetizer, std::vector<uint8_t>& result, const std::shared_ptr<Message>& message);
-	bool encode(const Packetizer& packetizer, std::vector<uint8_t>& result, Command cmd, bool boolean) {
-		return encode(packetizer, result, cmd, std::vector<uint8_t>({ (uint8_t)boolean }));
-	}
 	bool encode(const Packetizer& packetizer, std::vector<uint8_t>& result, Command cmd, std::vector<uint8_t> arguments = {});
 
 	bool supportCANFD = false;
+	bool supportEthPhy = false;
+
 private:
 	device_eventhandler_t report;
 };
 
 }
 
+#endif // __cplusplus
+
 #endif
\ No newline at end of file
