@@ -1,6 +1,8 @@
 #ifndef __PACKET_H_
 #define __PACKET_H_
 
+#ifdef __cplusplus
+
 #include "icsneo/communication/network.h"
 #include <vector>
 #include <stdint.h>
@@ -15,4 +17,6 @@ public:
 
 }
 
+#endif // __cplusplus
+
 #endif
\ No newline at end of file
