@@ -1,6 +1,8 @@
 #ifndef __FLEXRAYCHANNEL_H_
 #define __FLEXRAYCHANNEL_H_
 
+#ifdef __cplusplus
+
 #include <cstdint>
 
 namespace icsneo {
@@ -19,4 +21,6 @@ enum class Channel {
 
 } // namespace icsneo
 
+#endif // __cplusplus
+
 #endif // __FLEXRAYCHANNEL_H_
\ No newline at end of file
