@@ -1,16 +1,16 @@
-#ifndef __VALUECAN4_4_2EL_SETTINGS_H_
-#define __VALUECAN4_4_2EL_SETTINGS_H_
+#ifndef __VALUECAN4_2EL_SETTINGS_H_
+#define __VALUECAN4_2EL_SETTINGS_H_
 
 #include "icsneo/device/idevicesettings.h"
-#include "icsneo/device/tree/valuecan4/settings/valuecan4settings.h"
+#include "icsneo/device/tree/valuecan4/settings/valuecan4-4-2elsettings.h"
 
 #ifdef __cplusplus
 
 namespace icsneo {
 
-class ValueCAN4_4_2ELSettings : public IDeviceSettings {
+class ValueCAN4_2ELSettings : public ValueCAN4_4_2ELSettings {
 public:
-	ValueCAN4_4_2ELSettings(std::shared_ptr<Communication> com) : IDeviceSettings(com, sizeof(valuecan4_4_2el_settings_t)) {}
+	ValueCAN4_2ELSettings(std::shared_ptr<Communication> com) : ValueCAN4_4_2ELSettings(com) {}
 	const CAN_SETTINGS* getCANSettingsFor(Network net) const override {
 		auto cfg = getStructurePointer<valuecan4_4_2el_settings_t>();
 		if(cfg == nullptr)
@@ -38,6 +38,13 @@ public:
 		}
 	}
 
+	virtual std::vector<TerminationGroup> getTerminationGroups() const override {
+		return {
+			{ Network(Network::NetID::DWCAN_01) },
+			{ Network(Network::NetID::DWCAN_02) }
+		};
+	}
+
 	const LIN_SETTINGS* getLINSettingsFor(Network net) const override {
 		auto cfg = getStructurePointer<valuecan4_4_2el_settings_t>();
 		if(cfg == nullptr)
@@ -49,6 +56,14 @@ public:
 				return nullptr;
 		}
 	}
+
+protected:
+	ICSNEO_UNALIGNED(const uint64_t*) getTerminationEnables() const override {
+		auto cfg = getStructurePointer<valuecan4_4_2el_settings_t>();
+		if(cfg == nullptr)
+			return nullptr;
+		return &cfg->termination_enables;
+	}
 };
 
 }
